// MODULE : WAModbus.H
// Definitions required to use the Modbus DLL interface functions.


#ifndef __WAModbus_H__
#define __WAModbus_H__


#if defined(__cplusplus)
extern "C"
{
#endif

	// #include <windows.h>
typedef void * long;
typedef unsigned short * MODBUSBSTR;

#ifdef WAMODBUS_EXPORTS
 #define WAMODBUS_EXPORT 
#else
 #define WAMODBUS_EXPORT 
#endif


#define MAX_MODBUS_DATA_LENGTH 250


// Possible return values for WA_readModbusDevice(), WA_writeModbusDevice(), WA_readModbusDiagnostics()
#define HOST_REJECTED_DATA_LENGTH    -6
#define HOST_REJECTED_START_ADDRESS  -5
#define HOST_RECEIVED_IO_ERR_SENDING -4
#define HOST_RECEIVED_MODBUS_ERROR   -3	// Error set from controller, the MODBUS ERROR CODE
										// will be stored in data[0]
#define HOST_RECEIVED_TIMEOUT_ERROR  -2 // Timeout waiting for return string from slave.
#define HOST_RECEIVED_CHECKSUM_ERROR -1	// Slave's return string had a bad checksum

#define COMM_OK					0
// MODBUS ERROR CODES
#define ILLEGAL_FUNCTION		1
#define ILLEGAL_DATA_ADDRESS	2
#define ILLEGAL_DATA_VALUE		3
#define SLAVE_DEVICE_FAILURE	4
#define ACKNOWLEDGE				5
#define SLAVE_DEVICE_BUSY		6
#define NEGATIVE_ACKNOWLEDGE	7
#define MEMORY_PARITY_ERROR		8


// Port Settings
#define NOPARITY            0
#define ODDPARITY           1
#define EVENPARITY          2
#define MARKPARITY          3
#define SPACEPARITY         4


// Returned values for WA_openModbusConnection(), WA_openVBModbusConnection(), WA_closeModbusConnection()
#define BAD 1
#define GOOD 0



int __stdcall WA_openModbusConnection(long *hComm, char *portStr, long baudRate, short parity);
int __stdcall WA_readModbusDevice(long hComm, short slaveAddress, long startAddress, short *data, short numPoints);
int __stdcall WA_writeModbusDevice(long hComm, short slaveAddress, long startAddress, short *data, short numPoints);
void __stdcall WA_closeModbusConnection(long hComm);

int __stdcall WA_readModbusDiagnostics(long hComm, short slaveAddress, short subFunction, short *data);

int __stdcall WA_openVBModbusConnection(long *hComm, short *  bStr, long baudRate, short parity);

int __stdcall WA_getReadString(long *hComm, char *data);
int __stdcall WA_getWriteString(long *hComm, char *data);
int __stdcall WA_getReadResponse(long *hComm, char *data);
int __stdcall WA_getWriteResponse(long *hComm, char *data);

int __stdcall WA_readAnafazeDevice(long hComm, short ctlrAddr, long dataAddr, short *dataArry, short numItems, short dataSize, short *statusByte);
int __stdcall WA_writeAnafazeDevice(long hComm, short ctlrAddr, long dataAddr, short *dataArry, short numItems, short dataSize, short *statusByte);
int __stdcall WA_getAnafazeReadString(long *hComm, char *data);
int __stdcall WA_getAnafazeWriteString(long *hComm, char *data);
int __stdcall WA_getAnafazeReadResponse(long *hComm, char *data);
int __stdcall WA_getAnafazeWriteResponse(long *hComm, char *data);



#if defined(__cplusplus)
}
#endif

#endif /* __WAModbus_H__ */

